#!perl -T

use Test::More tests => 1;

BEGIN {
    use_ok( 'Task::FreecellSolver::Testing' );
}

diag( "Testing Task::FreecellSolver::Testing $Task::FreecellSolver::Testing::VERSION, Perl $], $^X" );
